aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorKenichi Handa <[email protected]>1998-05-18 00:59:38 +0000
committerKenichi Handa <[email protected]>1998-05-18 00:59:38 +0000
commitab45712c8f5242771a1adac67979ba7ebf663990 (patch)
tree3da431bd4c8f9d7d9914d76644b93ba5ddeb5ea9 /src
parent44893c8f3a0286aa06f0c4f7a5e9036da60d1683 (diff)
Change terms unify/unification to
translate/translation respectively throughtout the file.
Diffstat (limited to 'src')
-rw-r--r--src/coding.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/coding.h b/src/coding.h
index f5250ce4e9..103f623b37 100644
--- a/src/coding.h
+++ b/src/coding.h
@@ -374,9 +374,9 @@ struct coding_system
additional conversion, or nil. */
Lisp_Object pre_write_conversion;
- /* Character unification tables to look up, or nil. */
- Lisp_Object character_unification_table_for_decode;
- Lisp_Object character_unification_table_for_encode;
+ /* Character translation tables to look up, or nil. */
+ Lisp_Object character_translation_table_for_decode;
+ Lisp_Object character_translation_table_for_encode;
};
#define CODING_REQUIRE_FLUSHING_MASK 1
@@ -530,6 +530,9 @@ extern Lisp_Object Qraw_text;
extern Lisp_Object Qbuffer_file_coding_system;
extern Lisp_Object Vcoding_category_list;
+extern Lisp_Object Qcharacter_translation_table;
+extern Lisp_Object Qcharacter_translation_table_id;
+
/* Mnemonic character to indicate each type of end-of-line. */
extern int eol_mnemonic_unix, eol_mnemonic_dos, eol_mnemonic_mac;
/* Mnemonic character to indicate type of end-of-line is not yet decided. */